# This File GEN using nerdicons_gen.py

class Cod:

	# CHAR : 
	cod_account = "\ueb99"
	# CHAR : 
	cod_activate_breakpoints = "\uea97"
	# CHAR : 
	cod_add = "\uea60"
	# CHAR : 
	cod_archive = "\uea98"
	# CHAR : 
	cod_arrow_both = "\uea99"
	# CHAR : 
	cod_arrow_circle_down = "\uebfc"
	# CHAR : 
	cod_arrow_circle_left = "\uebfd"
	# CHAR : 
	cod_arrow_circle_right = "\uebfe"
	# CHAR : 
	cod_arrow_circle_up = "\uebff"
	# CHAR : 
	cod_arrow_down = "\uea9a"
	# CHAR : 
	cod_arrow_left = "\uea9b"
	# CHAR : 
	cod_arrow_right = "\uea9c"
	# CHAR : 
	cod_arrow_small_down = "\uea9d"
	# CHAR : 
	cod_arrow_small_left = "\uea9e"
	# CHAR : 
	cod_arrow_small_right = "\uea9f"
	# CHAR : 
	cod_arrow_small_up = "\ueaa0"
	# CHAR : 
	cod_arrow_swap = "\uebcb"
	# CHAR : 
	cod_arrow_up = "\ueaa1"
	# CHAR : 
	cod_azure = "\uebd8"
	# CHAR : 
	cod_azure_devops = "\uebe8"
	# CHAR : 
	cod_beaker = "\uea79"
	# CHAR : 
	cod_beaker_stop = "\uebe1"
	# CHAR : 
	cod_bell = "\ueaa2"
	# CHAR : 
	cod_bell_dot = "\ueb9a"
	# CHAR : 
	cod_bell_slash = "\uec08"
	# CHAR : 
	cod_bell_slash_dot = "\uec09"
	# CHAR : 
	cod_blank = "\uec03"
	# CHAR : 
	cod_bold = "\ueaa3"
	# CHAR : 
	cod_book = "\ueaa4"
	# CHAR : 
	cod_bookmark = "\ueaa5"
	# CHAR : 
	cod_bracket_dot = "\uebe5"
	# CHAR : 
	cod_bracket_error = "\uebe6"
	# CHAR : 
	cod_briefcase = "\ueaac"
	# CHAR : 
	cod_broadcast = "\ueaad"
	# CHAR : 
	cod_browser = "\ueaae"
	# CHAR : 
	cod_bug = "\ueaaf"
	# CHAR : 
	cod_calendar = "\ueab0"
	# CHAR : 
	cod_call_incoming = "\ueb92"
	# CHAR : 
	cod_call_outgoing = "\ueb93"
	# CHAR : 
	cod_case_sensitive = "\ueab1"
	# CHAR : 
	cod_check = "\ueab2"
	# CHAR : 
	cod_check_all = "\uebb1"
	# CHAR : 
	cod_checklist = "\ueab3"
	# CHAR : 
	cod_chevron_down = "\ueab4"
	# CHAR : 
	cod_chevron_left = "\ueab5"
	# CHAR : 
	cod_chevron_right = "\ueab6"
	# CHAR : 
	cod_chevron_up = "\ueab7"
	# CHAR : 
	cod_chip = "\uec19"
	# CHAR : 
	cod_chrome_close = "\ueab8"
	# CHAR : 
	cod_chrome_maximize = "\ueab9"
	# CHAR : 
	cod_chrome_minimize = "\ueaba"
	# CHAR : 
	cod_chrome_restore = "\ueabb"
	# CHAR : 
	cod_circle = "\ueabc"
	# CHAR : 
	cod_circle_filled = "\uea71"
	# CHAR : 
	cod_circle_large = "\uebb5"
	# CHAR : 
	cod_circle_large_filled = "\uebb4"
	# CHAR : 
	cod_circle_slash = "\ueabd"
	# CHAR : 
	cod_circle_small = "\uec07"
	# CHAR : 
	cod_circle_small_filled = "\ueb8a"
	# CHAR : 
	cod_circuit_board = "\ueabe"
	# CHAR : 
	cod_clear_all = "\ueabf"
	# CHAR : 
	cod_clippy = "\ueac0"
	# CHAR : 
	cod_close = "\uea76"
	# CHAR : 
	cod_close_all = "\ueac1"
	# CHAR : 
	cod_cloud = "\uebaa"
	# CHAR : 
	cod_cloud_download = "\ueac2"
	# CHAR : 
	cod_cloud_upload = "\ueac3"
	# CHAR : 
	cod_code = "\ueac4"
	# CHAR : 
	cod_coffee = "\uec15"
	# CHAR : 
	cod_collapse_all = "\ueac5"
	# CHAR : 
	cod_color_mode = "\ueac6"
	# CHAR : 
	cod_combine = "\uebb6"
	# CHAR : 
	cod_comment = "\uea6b"
	# CHAR : 
	cod_comment_discussion = "\ueac7"
	# CHAR : 
	cod_comment_draft = "\uec0e"
	# CHAR : 
	cod_comment_unresolved = "\uec0a"
	# CHAR : 
	cod_compass = "\uebd5"
	# CHAR : 
	cod_compass_active = "\uebd7"
	# CHAR : 
	cod_compass_dot = "\uebd6"
	# CHAR : 
	cod_copilot = "\uec1e"
	# CHAR : 
	cod_copy = "\uebcc"
	# CHAR : 
	cod_credit_card = "\ueac9"
	# CHAR : 
	cod_dash = "\ueacc"
	# CHAR : 
	cod_dashboard = "\ueacd"
	# CHAR : 
	cod_database = "\ueace"
	# CHAR : 
	cod_debug = "\uead8"
	# CHAR : 
	cod_debug_all = "\uebdc"
	# CHAR : 
	cod_debug_alt = "\ueb91"
	# CHAR : 
	cod_debug_alt_small = "\ueba8"
	# CHAR : 
	cod_debug_breakpoint_conditional = "\ueaa7"
	# CHAR : 
	cod_debug_breakpoint_conditional_unverified = "\ueaa6"
	# CHAR : 
	cod_debug_breakpoint_data = "\ueaa9"
	# CHAR : 
	cod_debug_breakpoint_data_unverified = "\ueaa8"
	# CHAR : 
	cod_debug_breakpoint_function = "\ueb88"
	# CHAR : 
	cod_debug_breakpoint_function_unverified = "\ueb87"
	# CHAR : 
	cod_debug_breakpoint_log = "\ueaab"
	# CHAR : 
	cod_debug_breakpoint_log_unverified = "\ueaaa"
	# CHAR : 
	cod_debug_breakpoint_unsupported = "\ueb8c"
	# CHAR : 
	cod_debug_console = "\ueb9b"
	# CHAR : 
	cod_debug_continue = "\ueacf"
	# CHAR : 
	cod_debug_continue_small = "\uebe0"
	# CHAR : 
	cod_debug_coverage = "\uebdd"
	# CHAR : 
	cod_debug_disconnect = "\uead0"
	# CHAR : 
	cod_debug_line_by_line = "\uebd0"
	# CHAR : 
	cod_debug_pause = "\uead1"
	# CHAR : 
	cod_debug_rerun = "\uebc0"
	# CHAR : 
	cod_debug_restart = "\uead2"
	# CHAR : 
	cod_debug_restart_frame = "\ueb90"
	# CHAR : 
	cod_debug_reverse_continue = "\ueb8e"
	# CHAR : 
	cod_debug_stackframe = "\ueb8b"
	# CHAR : 
	cod_debug_stackframe_active = "\ueb89"
	# CHAR : 
	cod_debug_start = "\uead3"
	# CHAR : 
	cod_debug_step_back = "\ueb8f"
	# CHAR : 
	cod_debug_step_into = "\uead4"
	# CHAR : 
	cod_debug_step_out = "\uead5"
	# CHAR : 
	cod_debug_step_over = "\uead6"
	# CHAR : 
	cod_debug_stop = "\uead7"
	# CHAR : 
	cod_desktop_download = "\uea78"
	# CHAR : 
	cod_device_camera = "\ueada"
	# CHAR : 
	cod_device_camera_video = "\uead9"
	# CHAR : 
	cod_device_mobile = "\ueadb"
	# CHAR : 
	cod_diff = "\ueae1"
	# CHAR : 
	cod_diff_added = "\ueadc"
	# CHAR : 
	cod_diff_ignored = "\ueadd"
	# CHAR : 
	cod_diff_modified = "\ueade"
	# CHAR : 
	cod_diff_removed = "\ueadf"
	# CHAR : 
	cod_diff_renamed = "\ueae0"
	# CHAR : 
	cod_discard = "\ueae2"
	# CHAR : 
	cod_edit = "\uea73"
	# CHAR : 
	cod_editor_layout = "\ueae3"
	# CHAR : 
	cod_ellipsis = "\uea7c"
	# CHAR : 
	cod_empty_window = "\ueae4"
	# CHAR : 
	cod_error = "\uea87"
	# CHAR : 
	cod_error_small = "\uebfb"
	# CHAR : 
	cod_exclude = "\ueae5"
	# CHAR : 
	cod_expand_all = "\ueb95"
	# CHAR : 
	cod_export = "\uebac"
	# CHAR : 
	cod_extensions = "\ueae6"
	# CHAR : 
	cod_eye = "\uea70"
	# CHAR : 
	cod_eye_closed = "\ueae7"
	# CHAR : 
	cod_feedback = "\ueb96"
	# CHAR : 
	cod_file = "\uea7b"
	# CHAR : 
	cod_file_binary = "\ueae8"
	# CHAR : 
	cod_file_code = "\ueae9"
	# CHAR : 
	cod_file_media = "\ueaea"
	# CHAR : 
	cod_file_pdf = "\ueaeb"
	# CHAR : 
	cod_file_submodule = "\ueaec"
	# CHAR : 
	cod_file_symlink_directory = "\ueaed"
	# CHAR : 
	cod_file_symlink_file = "\ueaee"
	# CHAR : 
	cod_file_zip = "\ueaef"
	# CHAR : 
	cod_files = "\ueaf0"
	# CHAR : 
	cod_filter = "\ueaf1"
	# CHAR : 
	cod_filter_filled = "\uebce"
	# CHAR : 
	cod_flame = "\ueaf2"
	# CHAR : 
	cod_fold = "\ueaf5"
	# CHAR : 
	cod_fold_down = "\ueaf3"
	# CHAR : 
	cod_fold_up = "\ueaf4"
	# CHAR : 
	cod_folder = "\uea83"
	# CHAR : 
	cod_folder_active = "\ueaf6"
	# CHAR : 
	cod_folder_library = "\uebdf"
	# CHAR : 
	cod_folder_opened = "\ueaf7"
	# CHAR : 
	cod_game = "\uec17"
	# CHAR : 
	cod_gear = "\ueaf8"
	# CHAR : 
	cod_gift = "\ueaf9"
	# CHAR : 
	cod_gist_secret = "\ueafa"
	# CHAR : 
	cod_git_commit = "\ueafc"
	# CHAR : 
	cod_git_compare = "\ueafd"
	# CHAR : 
	cod_git_fetch = "\uec1d"
	# CHAR : 
	cod_git_merge = "\ueafe"
	# CHAR : 
	cod_git_pull_request = "\uea64"
	# CHAR : 
	cod_git_pull_request_closed = "\uebda"
	# CHAR : 
	cod_git_pull_request_create = "\uebbc"
	# CHAR : 
	cod_git_pull_request_draft = "\uebdb"
	# CHAR : 
	cod_git_pull_request_go_to_changes = "\uec0b"
	# CHAR : 
	cod_git_pull_request_new_changes = "\uec0c"
	# CHAR : 
	cod_github = "\uea84"
	# CHAR : 
	cod_github_action = "\ueaff"
	# CHAR : 
	cod_github_alt = "\ueb00"
	# CHAR : 
	cod_github_inverted = "\ueba1"
	# CHAR : 
	cod_globe = "\ueb01"
	# CHAR : 
	cod_go_to_file = "\uea94"
	# CHAR : 
	cod_grabber = "\ueb02"
	# CHAR : 
	cod_graph = "\ueb03"
	# CHAR : 
	cod_graph_left = "\uebad"
	# CHAR : 
	cod_graph_line = "\uebe2"
	# CHAR : 
	cod_graph_scatter = "\uebe3"
	# CHAR : 
	cod_gripper = "\ueb04"
	# CHAR : 
	cod_group_by_ref_type = "\ueb97"
	# CHAR : 
	cod_heart = "\ueb05"
	# CHAR : 
	cod_heart_filled = "\uec04"
	# CHAR : 
	cod_history = "\uea82"
	# CHAR : 
	cod_home = "\ueb06"
	# CHAR : 
	cod_horizontal_rule = "\ueb07"
	# CHAR : 
	cod_hubot = "\ueb08"
	# CHAR : 
	cod_inbox = "\ueb09"
	# CHAR : 
	cod_indent = "\uebf9"
	# CHAR : 
	cod_info = "\uea74"
	# CHAR : 
	cod_insert = "\uec11"
	# CHAR : 
	cod_inspect = "\uebd1"
	# CHAR : 
	cod_issue_draft = "\uebd9"
	# CHAR : 
	cod_issue_reopened = "\ueb0b"
	# CHAR : 
	cod_issues = "\ueb0c"
	# CHAR : 
	cod_italic = "\ueb0d"
	# CHAR : 
	cod_jersey = "\ueb0e"
	# CHAR : 
	cod_json = "\ueb0f"
	# CHAR : 
	cod_kebab_vertical = "\ueb10"
	# CHAR : 
	cod_key = "\ueb11"
	# CHAR : 
	cod_law = "\ueb12"
	# CHAR : 
	cod_layers = "\uebd2"
	# CHAR : 
	cod_layers_active = "\uebd4"
	# CHAR : 
	cod_layers_dot = "\uebd3"
	# CHAR : 
	cod_layout = "\uebeb"
	# CHAR : 
	cod_layout_activitybar_left = "\uebec"
	# CHAR : 
	cod_layout_activitybar_right = "\uebed"
	# CHAR : 
	cod_layout_centered = "\uebf7"
	# CHAR : 
	cod_layout_menubar = "\uebf6"
	# CHAR : 
	cod_layout_panel = "\uebf2"
	# CHAR : 
	cod_layout_panel_center = "\uebef"
	# CHAR : 
	cod_layout_panel_justify = "\uebf0"
	# CHAR : 
	cod_layout_panel_left = "\uebee"
	# CHAR : 
	cod_layout_panel_off = "\uec01"
	# CHAR : 
	cod_layout_panel_right = "\uebf1"
	# CHAR : 
	cod_layout_sidebar_left = "\uebf3"
	# CHAR : 
	cod_layout_sidebar_left_off = "\uec02"
	# CHAR : 
	cod_layout_sidebar_right = "\uebf4"
	# CHAR : 
	cod_layout_sidebar_right_off = "\uec00"
	# CHAR : 
	cod_layout_statusbar = "\uebf5"
	# CHAR : 
	cod_library = "\ueb9c"
	# CHAR : 
	cod_lightbulb = "\uea61"
	# CHAR : 
	cod_lightbulb_autofix = "\ueb13"
	# CHAR : 
	cod_link = "\ueb15"
	# CHAR : 
	cod_link_external = "\ueb14"
	# CHAR : 
	cod_list_filter = "\ueb83"
	# CHAR : 
	cod_list_flat = "\ueb84"
	# CHAR : 
	cod_list_ordered = "\ueb16"
	# CHAR : 
	cod_list_selection = "\ueb85"
	# CHAR : 
	cod_list_tree = "\ueb86"
	# CHAR : 
	cod_list_unordered = "\ueb17"
	# CHAR : 
	cod_live_share = "\ueb18"
	# CHAR : 
	cod_loading = "\ueb19"
	# CHAR : 
	cod_location = "\ueb1a"
	# CHAR : 
	cod_lock = "\uea75"
	# CHAR : 
	cod_lock_small = "\uebe7"
	# CHAR : 
	cod_magnet = "\uebae"
	# CHAR : 
	cod_mail = "\ueb1c"
	# CHAR : 
	cod_mail_read = "\ueb1b"
	# CHAR : 
	cod_map = "\uec05"
	# CHAR : 
	cod_map_filled = "\uec06"
	# CHAR : 
	cod_markdown = "\ueb1d"
	# CHAR : 
	cod_megaphone = "\ueb1e"
	# CHAR : 
	cod_mention = "\ueb1f"
	# CHAR : 
	cod_menu = "\ueb94"
	# CHAR : 
	cod_merge = "\uebab"
	# CHAR : 
	cod_mic = "\uec12"
	# CHAR : 
	cod_mic_filled = "\uec1c"
	# CHAR : 
	cod_milestone = "\ueb20"
	# CHAR : 
	cod_mirror = "\uea69"
	# CHAR : 
	cod_mortar_board = "\ueb21"
	# CHAR : 
	cod_move = "\ueb22"
	# CHAR : 
	cod_multiple_windows = "\ueb23"
	# CHAR : 
	cod_music = "\uec1b"
	# CHAR : 
	cod_mute = "\ueb24"
	# CHAR : 
	cod_new_file = "\uea7f"
	# CHAR : 
	cod_new_folder = "\uea80"
	# CHAR : 
	cod_newline = "\uebea"
	# CHAR : 
	cod_no_newline = "\ueb25"
	# CHAR : 
	cod_note = "\ueb26"
	# CHAR : 
	cod_notebook = "\uebaf"
	# CHAR : 
	cod_notebook_template = "\uebbf"
	# CHAR : 
	cod_octoface = "\ueb27"
	# CHAR : 
	cod_open_preview = "\ueb28"
	# CHAR : 
	cod_organization = "\uea7e"
	# CHAR : 
	cod_output = "\ueb9d"
	# CHAR : 
	cod_package = "\ueb29"
	# CHAR : 
	cod_paintcan = "\ueb2a"
	# CHAR : 
	cod_pass = "\ueba4"
	# CHAR : 
	cod_pass_filled = "\uebb3"
	# CHAR : 
	cod_person = "\uea67"
	# CHAR : 
	cod_person_add = "\uebcd"
	# CHAR : 
	cod_piano = "\uec1a"
	# CHAR : 
	cod_pie_chart = "\uebe4"
	# CHAR : 
	cod_pin = "\ueb2b"
	# CHAR : 
	cod_pinned = "\ueba0"
	# CHAR : 
	cod_pinned_dirty = "\uebb2"
	# CHAR : 
	cod_play = "\ueb2c"
	# CHAR : 
	cod_play_circle = "\ueba6"
	# CHAR : 
	cod_plug = "\ueb2d"
	# CHAR : 
	cod_preserve_case = "\ueb2e"
	# CHAR : 
	cod_preview = "\ueb2f"
	# CHAR : 
	cod_primitive_square = "\uea72"
	# CHAR : 
	cod_project = "\ueb30"
	# CHAR : 
	cod_pulse = "\ueb31"
	# CHAR : 
	cod_question = "\ueb32"
	# CHAR : 
	cod_quote = "\ueb33"
	# CHAR : 
	cod_radio_tower = "\ueb34"
	# CHAR : 
	cod_reactions = "\ueb35"
	# CHAR : 
	cod_record = "\ueba7"
	# CHAR : 
	cod_record_keys = "\uea65"
	# CHAR : 
	cod_record_small = "\uebfa"
	# CHAR : 
	cod_redo = "\uebb0"
	# CHAR : 
	cod_references = "\ueb36"
	# CHAR : 
	cod_refresh = "\ueb37"
	# CHAR : 
	cod_regex = "\ueb38"
	# CHAR : 
	cod_remote = "\ueb3a"
	# CHAR : 
	cod_remote_explorer = "\ueb39"
	# CHAR : 
	cod_remove = "\ueb3b"
	# CHAR : 
	cod_replace = "\ueb3d"
	# CHAR : 
	cod_replace_all = "\ueb3c"
	# CHAR : 
	cod_reply = "\uea7d"
	# CHAR : 
	cod_repo = "\uea62"
	# CHAR : 
	cod_repo_clone = "\ueb3e"
	# CHAR : 
	cod_repo_force_push = "\ueb3f"
	# CHAR : 
	cod_repo_forked = "\uea63"
	# CHAR : 
	cod_repo_pull = "\ueb40"
	# CHAR : 
	cod_repo_push = "\ueb41"
	# CHAR : 
	cod_report = "\ueb42"
	# CHAR : 
	cod_request_changes = "\ueb43"
	# CHAR : 
	cod_rocket = "\ueb44"
	# CHAR : 
	cod_root_folder = "\ueb46"
	# CHAR : 
	cod_root_folder_opened = "\ueb45"
	# CHAR : 
	cod_rss = "\ueb47"
	# CHAR : 
	cod_ruby = "\ueb48"
	# CHAR : 
	cod_run_above = "\uebbd"
	# CHAR : 
	cod_run_all = "\ueb9e"
	# CHAR : 
	cod_run_below = "\uebbe"
	# CHAR : 
	cod_run_errors = "\uebde"
	# CHAR : 
	cod_save = "\ueb4b"
	# CHAR : 
	cod_save_all = "\ueb49"
	# CHAR : 
	cod_save_as = "\ueb4a"
	# CHAR : 
	cod_screen_full = "\ueb4c"
	# CHAR : 
	cod_screen_normal = "\ueb4d"
	# CHAR : 
	cod_search = "\uea6d"
	# CHAR : 
	cod_search_fuzzy = "\uec0d"
	# CHAR : 
	cod_search_stop = "\ueb4e"
	# CHAR : 
	cod_send = "\uec0f"
	# CHAR : 
	cod_server = "\ueb50"
	# CHAR : 
	cod_server_environment = "\ueba3"
	# CHAR : 
	cod_server_process = "\ueba2"
	# CHAR : 
	cod_settings = "\ueb52"
	# CHAR : 
	cod_settings_gear = "\ueb51"
	# CHAR : 
	cod_shield = "\ueb53"
	# CHAR : 
	cod_sign_in = "\uea6f"
	# CHAR : 
	cod_sign_out = "\uea6e"
	# CHAR : 
	cod_smiley = "\ueb54"
	# CHAR : 
	cod_snake = "\uec16"
	# CHAR : 
	cod_sort_precedence = "\ueb55"
	# CHAR : 
	cod_source_control = "\uea68"
	# CHAR : 
	cod_sparkle = "\uec10"
	# CHAR : 
	cod_split_horizontal = "\ueb56"
	# CHAR : 
	cod_split_vertical = "\ueb57"
	# CHAR : 
	cod_squirrel = "\ueb58"
	# CHAR : 
	cod_star_empty = "\uea6a"
	# CHAR : 
	cod_star_full = "\ueb59"
	# CHAR : 
	cod_star_half = "\ueb5a"
	# CHAR : 
	cod_stop_circle = "\ueba5"
	# CHAR : 
	cod_symbol_array = "\uea8a"
	# CHAR : 
	cod_symbol_boolean = "\uea8f"
	# CHAR : 
	cod_symbol_class = "\ueb5b"
	# CHAR : 
	cod_symbol_color = "\ueb5c"
	# CHAR : 
	cod_symbol_constant = "\ueb5d"
	# CHAR : 
	cod_symbol_enum = "\uea95"
	# CHAR : 
	cod_symbol_enum_member = "\ueb5e"
	# CHAR : 
	cod_symbol_event = "\uea86"
	# CHAR : 
	cod_symbol_field = "\ueb5f"
	# CHAR : 
	cod_symbol_file = "\ueb60"
	# CHAR : 
	cod_symbol_interface = "\ueb61"
	# CHAR : 
	cod_symbol_key = "\uea93"
	# CHAR : 
	cod_symbol_keyword = "\ueb62"
	# CHAR : 
	cod_symbol_method = "\uea8c"
	# CHAR : 
	cod_symbol_misc = "\ueb63"
	# CHAR : 
	cod_symbol_namespace = "\uea8b"
	# CHAR : 
	cod_symbol_numeric = "\uea90"
	# CHAR : 
	cod_symbol_operator = "\ueb64"
	# CHAR : 
	cod_symbol_parameter = "\uea92"
	# CHAR : 
	cod_symbol_property = "\ueb65"
	# CHAR : 
	cod_symbol_ruler = "\uea96"
	# CHAR : 
	cod_symbol_snippet = "\ueb66"
	# CHAR : 
	cod_symbol_string = "\ueb8d"
	# CHAR : 
	cod_symbol_structure = "\uea91"
	# CHAR : 
	cod_symbol_variable = "\uea88"
	# CHAR : 
	cod_sync = "\uea77"
	# CHAR : 
	cod_sync_ignored = "\ueb9f"
	# CHAR : 
	cod_table = "\uebb7"
	# CHAR : 
	cod_tag = "\uea66"
	# CHAR : 
	cod_target = "\uebf8"
	# CHAR : 
	cod_tasklist = "\ueb67"
	# CHAR : 
	cod_telescope = "\ueb68"
	# CHAR : 
	cod_terminal = "\uea85"
	# CHAR : 
	cod_terminal_bash = "\uebca"
	# CHAR : 
	cod_terminal_cmd = "\uebc4"
	# CHAR : 
	cod_terminal_debian = "\uebc5"
	# CHAR : 
	cod_terminal_linux = "\uebc6"
	# CHAR : 
	cod_terminal_powershell = "\uebc7"
	# CHAR : 
	cod_terminal_tmux = "\uebc8"
	# CHAR : 
	cod_terminal_ubuntu = "\uebc9"
	# CHAR : 
	cod_text_size = "\ueb69"
	# CHAR : 
	cod_three_bars = "\ueb6a"
	# CHAR : 
	cod_thumbsdown = "\ueb6b"
	# CHAR : 
	cod_thumbsdown_filled = "\uec13"
	# CHAR : 
	cod_thumbsup = "\ueb6c"
	# CHAR : 
	cod_thumbsup_filled = "\uec14"
	# CHAR : 
	cod_tools = "\ueb6d"
	# CHAR : 
	cod_trash = "\uea81"
	# CHAR : 
	cod_triangle_down = "\ueb6e"
	# CHAR : 
	cod_triangle_left = "\ueb6f"
	# CHAR : 
	cod_triangle_right = "\ueb70"
	# CHAR : 
	cod_triangle_up = "\ueb71"
	# CHAR : 
	cod_twitter = "\ueb72"
	# CHAR : 
	cod_type_hierarchy = "\uebb9"
	# CHAR : 
	cod_type_hierarchy_sub = "\uebba"
	# CHAR : 
	cod_type_hierarchy_super = "\uebbb"
	# CHAR : 
	cod_unfold = "\ueb73"
	# CHAR : 
	cod_ungroup_by_ref_type = "\ueb98"
	# CHAR : 
	cod_unlock = "\ueb74"
	# CHAR : 
	cod_unmute = "\ueb75"
	# CHAR : 
	cod_unverified = "\ueb76"
	# CHAR : 
	cod_variable_group = "\uebb8"
	# CHAR : 
	cod_verified = "\ueb77"
	# CHAR : 
	cod_verified_filled = "\uebe9"
	# CHAR : 
	cod_versions = "\ueb78"
	# CHAR : 
	cod_vm = "\uea7a"
	# CHAR : 
	cod_vm_active = "\ueb79"
	# CHAR : 
	cod_vm_connect = "\ueba9"
	# CHAR : 
	cod_vm_outline = "\ueb7a"
	# CHAR : 
	cod_vm_running = "\ueb7b"
	# CHAR : 
	cod_vr = "\uec18"
	# CHAR : 
	cod_wand = "\uebcf"
	# CHAR : 
	cod_warning = "\uea6c"
	# CHAR : 
	cod_watch = "\ueb7c"
	# CHAR : 
	cod_whitespace = "\ueb7d"
	# CHAR : 
	cod_whole_word = "\ueb7e"
	# CHAR : 
	cod_window = "\ueb7f"
	# CHAR : 
	cod_word_wrap = "\ueb80"
	# CHAR : 
	cod_workspace_trusted = "\uebc1"
	# CHAR : 
	cod_workspace_unknown = "\uebc3"
	# CHAR : 
	cod_workspace_untrusted = "\uebc2"
	# CHAR : 
	cod_zoom_in = "\ueb81"
	# CHAR : 
	cod_zoom_out = "\ueb82"


# This File GEN using nerdicons_gen.py

class Dev:

	# CHAR : 
	dev_aarch64 = "\ue700"
	# CHAR : 
	dev_adonisjs = "\ue701"
	# CHAR : 
	dev_aftereffects = "\ue705"
	# CHAR : 
	dev_akka = "\ue708"
	# CHAR : 
	dev_algolia = "\ue70a"
	# CHAR : 
	dev_alpinejs = "\ue713"
	# CHAR : 
	dev_amazonwebservices = "\ue7ad"
	# CHAR : 
	dev_anaconda = "\ue715"
	# CHAR : 
	dev_android = "\ue70e"
	# CHAR : 
	dev_androidstudio = "\ue71a"
	# CHAR : 
	dev_angular = "\ue753"
	# CHAR : 
	dev_angularjs = "\ue71c"
	# CHAR : 
	dev_angularmaterial = "\ue720"
	# CHAR : 
	dev_ansible = "\ue723"
	# CHAR : 
	dev_antdesign = "\ue72a"
	# CHAR : 
	dev_apache = "\ue72b"
	# CHAR : 
	dev_apacheairflow = "\ue72c"
	# CHAR : 
	dev_apachekafka = "\ue72e"
	# CHAR : 
	dev_apachespark = "\ue72f"
	# CHAR : 
	dev_apl = "\ue730"
	# CHAR : 
	dev_appcelerator = "\ue7ab"
	# CHAR : 
	dev_apple = "\ue711"
	# CHAR : 
	dev_appwrite = "\ue731"
	# CHAR : 
	dev_archlinux = "\ue732"
	# CHAR : 
	dev_arduino = "\ue733"
	# CHAR : 
	dev_argocd = "\ue734"
	# CHAR : 
	dev_astro = "\ue735"
	# CHAR : 
	dev_atom = "\ue764"
	# CHAR : 
	dev_awk = "\ue741"
	# CHAR : 
	dev_aws = "\ue7ad"
	# CHAR : 
	dev_axios = "\ue74f"
	# CHAR : 
	dev_azure = "\ue754"
	# CHAR : 
	dev_azuredevops = "\ue756"
	# CHAR : 
	dev_azuresqldatabase = "\ue75b"
	# CHAR : 
	dev_babel = "\ue75d"
	# CHAR : 
	dev_backbone = "\ue752"
	# CHAR : 
	dev_backbonejs = "\ue752"
	# CHAR : 
	dev_ballerina = "\ue75e"
	# CHAR : 
	dev_bamboo = "\ue75f"
	# CHAR : 
	dev_bash = "\ue760"
	# CHAR : 
	dev_beats = "\ue761"
	# CHAR : 
	dev_behance = "\ue762"
	# CHAR : 
	dev_bitbucket = "\ue703"
	# CHAR : 
	dev_blazor = "\ue765"
	# CHAR : 
	dev_blender = "\ue766"
	# CHAR : 
	dev_bootstrap = "\ue747"
	# CHAR : 
	dev_bower = "\ue74d"
	# CHAR : 
	dev_browserstack = "\ue76b"
	# CHAR : 
	dev_bulma = "\ue76c"
	# CHAR : 
	dev_bun = "\ue76f"
	# CHAR : 
	dev_c = "\ue771"
	# CHAR : 
	dev_c_lang = "\ue771"
	# CHAR : 
	dev_cairo = "\ue773"
	# CHAR : 
	dev_cakephp = "\ue77a"
	# CHAR : 
	dev_canva = "\ue77c"
	# CHAR : 
	dev_capacitor = "\ue785"
	# CHAR : 
	dev_carbon = "\ue788"
	# CHAR : 
	dev_cassandra = "\ue789"
	# CHAR : 
	dev_centos = "\ue78a"
	# CHAR : 
	dev_ceylon = "\ue78b"
	# CHAR : 
	dev_chrome = "\ue743"
	# CHAR : 
	dev_circleci = "\ue78c"
	# CHAR : 
	dev_clarity = "\ue78d"
	# CHAR : 
	dev_clion = "\ue78e"
	# CHAR : 
	dev_clojure = "\ue768"
	# CHAR : 
	dev_clojure_alt = "\ue76a"
	# CHAR : 
	dev_clojurescript = "\ue790"
	# CHAR : 
	dev_cloudflare = "\ue792"
	# CHAR : 
	dev_cloudflareworkers = "\ue793"
	# CHAR : 
	dev_cmake = "\ue794"
	# CHAR : 
	dev_codeac = "\ue796"
	# CHAR : 
	dev_codecov = "\ue797"
	# CHAR : 
	dev_codeigniter = "\ue780"
	# CHAR : 
	dev_codepen = "\ue716"
	# CHAR : 
	dev_coffeescript = "\ue751"
	# CHAR : 
	dev_composer = "\ue783"
	# CHAR : 
	dev_confluence = "\ue799"
	# CHAR : 
	dev_consul = "\ue79a"
	# CHAR : 
	dev_contao = "\ue79b"
	# CHAR : 
	dev_corejs = "\ue79d"
	# CHAR : 
	dev_cosmosdb = "\ue79f"
	# CHAR : 
	dev_couchbase = "\ue7a0"
	# CHAR : 
	dev_couchdb = "\ue7a2"
	# CHAR : 
	dev_cplusplus = "\ue7a3"
	# CHAR : 
	dev_crystal = "\ue7ac"
	# CHAR : 
	dev_csharp = "\ue7b2"
	# CHAR : 
	dev_css3 = "\ue749"
	# CHAR : 
	dev_css3_full = "\ue74a"
	# CHAR : 
	dev_cucumber = "\ue7b7"
	# CHAR : 
	dev_cypressio = "\ue7b9"
	# CHAR : 
	dev_d3js = "\ue7bc"
	# CHAR : 
	dev_dart = "\ue798"
	# CHAR : 
	dev_database = "\ue706"
	# CHAR : 
	dev_datagrip = "\ue7bd"
	# CHAR : 
	dev_dataspell = "\ue7be"
	# CHAR : 
	dev_dbeaver = "\ue7bf"
	# CHAR : 
	dev_debian = "\ue77d"
	# CHAR : 
	dev_denojs = "\ue7c0"
	# CHAR : 
	dev_devicon = "\ue7c1"
	# CHAR : 
	dev_digital_ocean = "\ue7ae"
	# CHAR : 
	dev_digitalocean = "\ue7ae"
	# CHAR : 
	dev_discordjs = "\ue7c2"
	# CHAR : 
	dev_django = "\ue71d"
	# CHAR : 
	dev_djangorest = "\ue7c3"
	# CHAR : 
	dev_dlang = "\ue7af"
	# CHAR : 
	dev_docker = "\ue7b0"
	# CHAR : 
	dev_doctrine = "\ue774"
	# CHAR : 
	dev_dotnet = "\ue77f"
	# CHAR : 
	dev_dotnetcore = "\ue7c6"
	# CHAR : 
	dev_dreamweaver = "\ue79c"
	# CHAR : 
	dev_dropbox = "\ue707"
	# CHAR : 
	dev_dropwizard = "\ue7c7"
	# CHAR : 
	dev_drupal = "\ue742"
	# CHAR : 
	dev_dynamodb = "\ue7c8"
	# CHAR : 
	dev_eclipse = "\ue79e"
	# CHAR : 
	dev_ecto = "\ue7c9"
	# CHAR : 
	dev_elasticsearch = "\ue7ca"
	# CHAR : 
	dev_electron = "\ue7cb"
	# CHAR : 
	dev_eleventy = "\ue7cc"
	# CHAR : 
	dev_elixir = "\ue7cd"
	# CHAR : 
	dev_elm = "\ue7ce"
	# CHAR : 
	dev_emacs = "\ue7cf"
	# CHAR : 
	dev_embeddedc = "\ue7d0"
	# CHAR : 
	dev_ember = "\ue71b"
	# CHAR : 
	dev_envoy = "\ue7d1"
	# CHAR : 
	dev_erlang = "\ue7b1"
	# CHAR : 
	dev_eslint = "\ue7d2"
	# CHAR : 
	dev_express = "\ue7d3"
	# CHAR : 
	dev_facebook = "\ue7d4"
	# CHAR : 
	dev_fastapi = "\ue7d5"
	# CHAR : 
	dev_fastify = "\ue7d6"
	# CHAR : 
	dev_faunadb = "\ue7d7"
	# CHAR : 
	dev_feathersjs = "\ue7d8"
	# CHAR : 
	dev_fedora = "\ue7d9"
	# CHAR : 
	dev_figma = "\ue7da"
	# CHAR : 
	dev_filezilla = "\ue7db"
	# CHAR : 
	dev_firebase = "\ue787"
	# CHAR : 
	dev_firefox = "\ue745"
	# CHAR : 
	dev_flask = "\ue7dc"
	# CHAR : 
	dev_flutter = "\ue7dd"
	# CHAR : 
	dev_fortran = "\ue7de"
	# CHAR : 
	dev_foundation = "\ue7df"
	# CHAR : 
	dev_framermotion = "\ue7e0"
	# CHAR : 
	dev_framework7 = "\ue7e1"
	# CHAR : 
	dev_fsharp = "\ue7a7"
	# CHAR : 
	dev_gatling = "\ue7e2"
	# CHAR : 
	dev_gatsby = "\ue7e3"
	# CHAR : 
	dev_gazebo = "\ue7e4"
	# CHAR : 
	dev_gcc = "\ue7e5"
	# CHAR : 
	dev_gentoo = "\ue7e6"
	# CHAR : 
	dev_ghost = "\ue71f"
	# CHAR : 
	dev_ghost_small = "\ue714"
	# CHAR : 
	dev_gimp = "\ue7e7"
	# CHAR : 
	dev_git = "\ue702"
	# CHAR : 
	dev_git_branch = "\ue725"
	# CHAR : 
	dev_git_commit = "\ue729"
	# CHAR : 
	dev_git_compare = "\ue728"
	# CHAR : 
	dev_git_merge = "\ue727"
	# CHAR : 
	dev_git_pull_request = "\ue726"
	# CHAR : 
	dev_gitbook = "\ue7e8"
	# CHAR : 
	dev_github = "\ue709"
	# CHAR : 
	dev_github_badge = "\ue709"
	# CHAR : 
	dev_github_full = "\ue717"
	# CHAR : 
	dev_githubactions = "\ue7e9"
	# CHAR : 
	dev_githubcodespaces = "\ue7ea"
	# CHAR : 
	dev_gitlab = "\ue7eb"
	# CHAR : 
	dev_gitpod = "\ue7ec"
	# CHAR : 
	dev_gitter = "\ue7ed"
	# CHAR : 
	dev_gnu = "\ue779"
	# CHAR : 
	dev_go = "\ue724"
	# CHAR : 
	dev_godot = "\ue7ee"
	# CHAR : 
	dev_goland = "\ue7ef"
	# CHAR : 
	dev_google = "\ue7f0"
	# CHAR : 
	dev_googlecloud = "\ue7f1"
	# CHAR : 
	dev_gradle = "\ue7f2"
	# CHAR : 
	dev_grafana = "\ue7f3"
	# CHAR : 
	dev_grails = "\ue7b3"
	# CHAR : 
	dev_graphql = "\ue7f4"
	# CHAR : 
	dev_groovy = "\ue775"
	# CHAR : 
	dev_grpc = "\ue7f5"
	# CHAR : 
	dev_grunt = "\ue74c"
	# CHAR : 
	dev_gulp = "\ue763"
	# CHAR : 
	dev_hadoop = "\ue7f6"
	# CHAR : 
	dev_handlebars = "\ue7f7"
	# CHAR : 
	dev_hardhat = "\ue7f8"
	# CHAR : 
	dev_harvester = "\ue7f9"
	# CHAR : 
	dev_haskell = "\ue777"
	# CHAR : 
	dev_haxe = "\ue7fa"
	# CHAR : 
	dev_helm = "\ue7fb"
	# CHAR : 
	dev_heroku = "\ue77b"
	# CHAR : 
	dev_hibernate = "\ue7fc"
	# CHAR : 
	dev_homebrew = "\ue7fd"
	# CHAR : 
	dev_html5 = "\ue736"
	# CHAR : 
	dev_hugo = "\ue7fe"
	# CHAR : 
	dev_ie = "\ue744"
	# CHAR : 
	dev_ifttt = "\ue7ff"
	# CHAR : 
	dev_illustrator = "\ue7b4"
	# CHAR : 
	dev_influxdb = "\ue800"
	# CHAR : 
	dev_inkscape = "\ue801"
	# CHAR : 
	dev_insomnia = "\ue802"
	# CHAR : 
	dev_intellij = "\ue7b5"
	# CHAR : 
	dev_ionic = "\ue7a9"
	# CHAR : 
	dev_jaegertracing = "\ue803"
	# CHAR : 
	dev_jamstack = "\ue804"
	# CHAR : 
	dev_jasmine = "\ue805"
	# CHAR : 
	dev_java = "\ue738"
	# CHAR : 
	dev_javascript = "\ue781"
	# CHAR : 
	dev_javascript_alt = "\ue74e"
	# CHAR : 
	dev_javascript_badge = "\ue781"
	# CHAR : 
	dev_jeet = "\ue806"
	# CHAR : 
	dev_jekyll = "\ue70d"
	# CHAR : 
	dev_jekyll_small = "\ue70d"
	# CHAR : 
	dev_jenkins = "\ue767"
	# CHAR : 
	dev_jest = "\ue807"
	# CHAR : 
	dev_jetbrains = "\ue808"
	# CHAR : 
	dev_jetpackcompose = "\ue809"
	# CHAR : 
	dev_jira = "\ue75c"
	# CHAR : 
	dev_jiraalign = "\ue80a"
	# CHAR : 
	dev_jquery = "\ue750"
	# CHAR : 
	dev_json = "\ue80b"
	# CHAR : 
	dev_jule = "\ue80c"
	# CHAR : 
	dev_julia = "\ue80d"
	# CHAR : 
	dev_junit = "\ue80e"
	# CHAR : 
	dev_jupyter = "\ue80f"
	# CHAR : 
	dev_k3os = "\ue810"
	# CHAR : 
	dev_k3s = "\ue811"
	# CHAR : 
	dev_k6 = "\ue812"
	# CHAR : 
	dev_kaggle = "\ue813"
	# CHAR : 
	dev_karatelabs = "\ue814"
	# CHAR : 
	dev_karma = "\ue815"
	# CHAR : 
	dev_kdeneon = "\ue816"
	# CHAR : 
	dev_keras = "\ue817"
	# CHAR : 
	dev_kibana = "\ue818"
	# CHAR : 
	dev_knexjs = "\ue819"
	# CHAR : 
	dev_knockout = "\ue81a"
	# CHAR : 
	dev_kotlin = "\ue81b"
	# CHAR : 
	dev_krakenjs = "\ue784"
	# CHAR : 
	dev_krakenjs_badge = "\ue784"
	# CHAR : 
	dev_ktor = "\ue81c"
	# CHAR : 
	dev_kubernetes = "\ue81d"
	# CHAR : 
	dev_labview = "\ue81e"
	# CHAR : 
	dev_laravel = "\ue73f"
	# CHAR : 
	dev_latex = "\ue81f"
	# CHAR : 
	dev_less = "\ue758"
	# CHAR : 
	dev_linkedin = "\ue820"
	# CHAR : 
	dev_linux = "\ue712"
	# CHAR : 
	dev_liquibase = "\ue821"
	# CHAR : 
	dev_livewire = "\ue822"
	# CHAR : 
	dev_llvm = "\ue823"
	# CHAR : 
	dev_lodash = "\ue824"
	# CHAR : 
	dev_logstash = "\ue825"
	# CHAR : 
	dev_lua = "\ue826"
	# CHAR : 
	dev_lumen = "\ue827"
	# CHAR : 
	dev_magento = "\ue740"
	# CHAR : 
	dev_mariadb = "\ue828"
	# CHAR : 
	dev_markdown = "\ue73e"
	# CHAR : 
	dev_materializecss = "\ue7b6"
	# CHAR : 
	dev_materialui = "\ue829"
	# CHAR : 
	dev_matlab = "\ue82a"
	# CHAR : 
	dev_matplotlib = "\ue82b"
	# CHAR : 
	dev_maven = "\ue82c"
	# CHAR : 
	dev_maya = "\ue82d"
	# CHAR : 
	dev_meteor = "\ue7a5"
	# CHAR : 
	dev_meteorfull = "\ue7a6"
	# CHAR : 
	dev_microsoftsqlserver = "\ue82e"
	# CHAR : 
	dev_minitab = "\ue82f"
	# CHAR : 
	dev_mithril = "\ue830"
	# CHAR : 
	dev_mobx = "\ue831"
	# CHAR : 
	dev_mocha = "\ue832"
	# CHAR : 
	dev_modx = "\ue833"
	# CHAR : 
	dev_moleculer = "\ue834"
	# CHAR : 
	dev_mongodb = "\ue7a4"
	# CHAR : 
	dev_mongoose = "\ue835"
	# CHAR : 
	dev_moodle = "\ue836"
	# CHAR : 
	dev_mootools_badge = "\ue78f"
	# CHAR : 
	dev_mozilla = "\ue786"
	# CHAR : 
	dev_msdos = "\ue837"
	# CHAR : 
	dev_mysql = "\ue704"
	# CHAR : 
	dev_nano = "\ue838"
	# CHAR : 
	dev_neo4j = "\ue839"
	# CHAR : 
	dev_neovim = "\ue83a"
	# CHAR : 
	dev_nestjs = "\ue83b"
	# CHAR : 
	dev_netlify = "\ue83c"
	# CHAR : 
	dev_networkx = "\ue83d"
	# CHAR : 
	dev_nextjs = "\ue83e"
	# CHAR : 
	dev_nginx = "\ue776"
	# CHAR : 
	dev_ngrx = "\ue83f"
	# CHAR : 
	dev_nhibernate = "\ue840"
	# CHAR : 
	dev_nim = "\ue841"
	# CHAR : 
	dev_nimble = "\ue842"
	# CHAR : 
	dev_nixos = "\ue843"
	# CHAR : 
	dev_nodejs = "\ue719"
	# CHAR : 
	dev_nodejs_small = "\ue718"
	# CHAR : 
	dev_nodemon = "\ue844"
	# CHAR : 
	dev_nodewebkit = "\ue845"
	# CHAR : 
	dev_nomad = "\ue846"
	# CHAR : 
	dev_norg = "\ue847"
	# CHAR : 
	dev_notion = "\ue848"
	# CHAR : 
	dev_npm = "\ue71e"
	# CHAR : 
	dev_nuget = "\ue849"
	# CHAR : 
	dev_numpy = "\ue84a"
	# CHAR : 
	dev_nuxtjs = "\ue84b"
	# CHAR : 
	dev_oauth = "\ue84c"
	# CHAR : 
	dev_objectivec = "\ue84d"
	# CHAR : 
	dev_ocaml = "\ue84e"
	# CHAR : 
	dev_ohmyzsh = "\ue84f"
	# CHAR : 
	dev_okta = "\ue850"
	# CHAR : 
	dev_openal = "\ue851"
	# CHAR : 
	dev_openapi = "\ue852"
	# CHAR : 
	dev_opencl = "\ue853"
	# CHAR : 
	dev_opencv = "\ue854"
	# CHAR : 
	dev_opengl = "\ue855"
	# CHAR : 
	dev_openstack = "\ue856"
	# CHAR : 
	dev_opensuse = "\ue857"
	# CHAR : 
	dev_opentelemetry = "\ue858"
	# CHAR : 
	dev_opera = "\ue746"
	# CHAR : 
	dev_oracle = "\ue859"
	# CHAR : 
	dev_ory = "\ue85a"
	# CHAR : 
	dev_p5js = "\ue85b"
	# CHAR : 
	dev_packer = "\ue85c"
	# CHAR : 
	dev_pandas = "\ue85d"
	# CHAR : 
	dev_perl = "\ue769"
	# CHAR : 
	dev_pfsense = "\ue85e"
	# CHAR : 
	dev_phalcon = "\ue85f"
	# CHAR : 
	dev_phoenix = "\ue860"
	# CHAR : 
	dev_photonengine = "\ue861"
	# CHAR : 
	dev_photoshop = "\ue7b8"
	# CHAR : 
	dev_php = "\ue73d"
	# CHAR : 
	dev_phpstorm = "\ue862"
	# CHAR : 
	dev_playwright = "\ue863"
	# CHAR : 
	dev_plotly = "\ue864"
	# CHAR : 
	dev_pnpm = "\ue865"
	# CHAR : 
	dev_podman = "\ue866"
	# CHAR : 
	dev_poetry = "\ue867"
	# CHAR : 
	dev_polygon = "\ue868"
	# CHAR : 
	dev_portainer = "\ue869"
	# CHAR : 
	dev_postcss = "\ue86a"
	# CHAR : 
	dev_postgresql = "\ue76e"
	# CHAR : 
	dev_postman = "\ue86b"
	# CHAR : 
	dev_powershell = "\ue86c"
	# CHAR : 
	dev_premierepro = "\ue86d"
	# CHAR : 
	dev_prisma = "\ue86e"
	# CHAR : 
	dev_processing = "\ue86f"
	# CHAR : 
	dev_prolog = "\ue7a1"
	# CHAR : 
	dev_prometheus = "\ue870"
	# CHAR : 
	dev_protractor = "\ue871"
	# CHAR : 
	dev_pulsar = "\ue872"
	# CHAR : 
	dev_pulumi = "\ue873"
	# CHAR : 
	dev_puppeteer = "\ue874"
	# CHAR : 
	dev_purescript = "\ue875"
	# CHAR : 
	dev_putty = "\ue876"
	# CHAR : 
	dev_pycharm = "\ue877"
	# CHAR : 
	dev_pypi = "\ue878"
	# CHAR : 
	dev_pyscript = "\ue879"
	# CHAR : 
	dev_pytest = "\ue87a"
	# CHAR : 
	dev_python = "\ue73c"
	# CHAR : 
	dev_pytorch = "\ue87b"
	# CHAR : 
	dev_qodana = "\ue87c"
	# CHAR : 
	dev_qt = "\ue87d"
	# CHAR : 
	dev_quarkus = "\ue87e"
	# CHAR : 
	dev_quasar = "\ue87f"
	# CHAR : 
	dev_qwik = "\ue880"
	# CHAR : 
	dev_r = "\ue881"
	# CHAR : 
	dev_rabbitmq = "\ue882"
	# CHAR : 
	dev_rails = "\ue73b"
	# CHAR : 
	dev_railway = "\ue883"
	# CHAR : 
	dev_rancher = "\ue884"
	# CHAR : 
	dev_raspberry_pi = "\ue722"
	# CHAR : 
	dev_reach = "\ue885"
	# CHAR : 
	dev_react = "\ue7ba"
	# CHAR : 
	dev_reactbootstrap = "\ue886"
	# CHAR : 
	dev_reactnavigation = "\ue887"
	# CHAR : 
	dev_reactrouter = "\ue888"
	# CHAR : 
	dev_readthedocs = "\ue889"
	# CHAR : 
	dev_realm = "\ue88a"
	# CHAR : 
	dev_rect = "\ue88b"
	# CHAR : 
	dev_redhat = "\ue7bb"
	# CHAR : 
	dev_redis = "\ue76d"
	# CHAR : 
	dev_redux = "\ue88c"
	# CHAR : 
	dev_renpy = "\ue88d"
	# CHAR : 
	dev_replit = "\ue88e"
	# CHAR : 
	dev_requirejs = "\ue770"
	# CHAR : 
	dev_rider = "\ue88f"
	# CHAR : 
	dev_rocksdb = "\ue890"
	# CHAR : 
	dev_rockylinux = "\ue891"
	# CHAR : 
	dev_rollup = "\ue892"
	# CHAR : 
	dev_ros = "\ue893"
	# CHAR : 
	dev_rspec = "\ue894"
	# CHAR : 
	dev_rstudio = "\ue895"
	# CHAR : 
	dev_ruby = "\ue739"
	# CHAR : 
	dev_ruby_on_rails = "\ue73b"
	# CHAR : 
	dev_ruby_rough = "\ue791"
	# CHAR : 
	dev_rubymine = "\ue896"
	# CHAR : 
	dev_rust = "\ue7a8"
	# CHAR : 
	dev_rxjs = "\ue897"
	# CHAR : 
	dev_safari = "\ue748"
	# CHAR : 
	dev_salesforce = "\ue898"
	# CHAR : 
	dev_sanity = "\ue899"
	# CHAR : 
	dev_sass = "\ue74b"
	# CHAR : 
	dev_scala = "\ue737"
	# CHAR : 
	dev_scalingo = "\ue89a"
	# CHAR : 
	dev_scikitlearn = "\ue89b"
	# CHAR : 
	dev_sdl = "\ue89c"
	# CHAR : 
	dev_selenium = "\ue89d"
	# CHAR : 
	dev_sema = "\ue89e"
	# CHAR : 
	dev_sentry = "\ue89f"
	# CHAR : 
	dev_sequelize = "\ue8a0"
	# CHAR : 
	dev_shopware = "\ue8a1"
	# CHAR : 
	dev_shotgrid = "\ue8a2"
	# CHAR : 
	dev_sketch = "\ue8a3"
	# CHAR : 
	dev_slack = "\ue8a4"
	# CHAR : 
	dev_smashing_magazine = "\ue72d"
	# CHAR : 
	dev_socketio = "\ue8a5"
	# CHAR : 
	dev_solidity = "\ue8a6"
	# CHAR : 
	dev_solidjs = "\ue8a7"
	# CHAR : 
	dev_sonarqube = "\ue8a8"
	# CHAR : 
	dev_sourcetree = "\ue8a9"
	# CHAR : 
	dev_spack = "\ue8aa"
	# CHAR : 
	dev_splunk = "\ue8ab"
	# CHAR : 
	dev_spring = "\ue8ac"
	# CHAR : 
	dev_spss = "\ue8ad"
	# CHAR : 
	dev_spyder = "\ue8ae"
	# CHAR : 
	dev_sqlalchemy = "\ue8af"
	# CHAR : 
	dev_sqldeveloper = "\ue8b0"
	# CHAR : 
	dev_sqlite = "\ue7c4"
	# CHAR : 
	dev_ssh = "\ue8b1"
	# CHAR : 
	dev_stackoverflow = "\ue710"
	# CHAR : 
	dev_stata = "\ue8b2"
	# CHAR : 
	dev_storybook = "\ue8b3"
	# CHAR : 
	dev_streamlit = "\ue8b4"
	# CHAR : 
	dev_stylus = "\ue759"
	# CHAR : 
	dev_sublime = "\ue7aa"
	# CHAR : 
	dev_subversion = "\ue8b5"
	# CHAR : 
	dev_supabase = "\ue8b6"
	# CHAR : 
	dev_svelte = "\ue8b7"
	# CHAR : 
	dev_swagger = "\ue8b8"
	# CHAR : 
	dev_swift = "\ue755"
	# CHAR : 
	dev_swiper = "\ue8b9"
	# CHAR : 
	dev_symfony = "\ue757"
	# CHAR : 
	dev_symfony_badge = "\ue757"
	# CHAR : 
	dev_tailwindcss = "\ue8ba"
	# CHAR : 
	dev_tauri = "\ue8bb"
	# CHAR : 
	dev_tensorflow = "\ue8bc"
	# CHAR : 
	dev_terminal = "\ue795"
	# CHAR : 
	dev_terraform = "\ue8bd"
	# CHAR : 
	dev_tex = "\ue8be"
	# CHAR : 
	dev_thealgorithms = "\ue8bf"
	# CHAR : 
	dev_threedsmax = "\ue8c0"
	# CHAR : 
	dev_threejs = "\ue8c1"
	# CHAR : 
	dev_titaniumsdk = "\ue8c2"
	# CHAR : 
	dev_tomcat = "\ue8c3"
	# CHAR : 
	dev_tortoisegit = "\ue8c4"
	# CHAR : 
	dev_towergit = "\ue8c5"
	# CHAR : 
	dev_traefikmesh = "\ue8c6"
	# CHAR : 
	dev_traefikproxy = "\ue8c7"
	# CHAR : 
	dev_travis = "\ue77e"
	# CHAR : 
	dev_trello = "\ue75a"
	# CHAR : 
	dev_trpc = "\ue8c8"
	# CHAR : 
	dev_twitter = "\ue8c9"
	# CHAR : 
	dev_typescript = "\ue8ca"
	# CHAR : 
	dev_typo3 = "\ue772"
	# CHAR : 
	dev_ubuntu = "\ue73a"
	# CHAR : 
	dev_uml = "\ue8cb"
	# CHAR : 
	dev_unifiedmodelinglanguage = "\ue8cb"
	# CHAR : 
	dev_unity = "\ue721"
	# CHAR : 
	dev_unity_small = "\ue721"
	# CHAR : 
	dev_unix = "\ue8cc"
	# CHAR : 
	dev_unrealengine = "\ue8cd"
	# CHAR : 
	dev_uwsgi = "\ue8ce"
	# CHAR : 
	dev_v8 = "\ue8cf"
	# CHAR : 
	dev_vagrant = "\ue8d0"
	# CHAR : 
	dev_vala = "\ue8d1"
	# CHAR : 
	dev_vault = "\ue8d2"
	# CHAR : 
	dev_vercel = "\ue8d3"
	# CHAR : 
	dev_vertx = "\ue8d4"
	# CHAR : 
	dev_vim = "\ue7c5"
	# CHAR : 
	dev_visualbasic = "\ue8d5"
	# CHAR : 
	dev_visualstudio = "\ue70c"
	# CHAR : 
	dev_vite = "\ue8d6"
	# CHAR : 
	dev_vitejs = "\ue8d7"
	# CHAR : 
	dev_vitess = "\ue8d8"
	# CHAR : 
	dev_vitest = "\ue8d9"
	# CHAR : 
	dev_vscode = "\ue8da"
	# CHAR : 
	dev_vsphere = "\ue8db"
	# CHAR : 
	dev_vuejs = "\ue8dc"
	# CHAR : 
	dev_vuestorefront = "\ue8dd"
	# CHAR : 
	dev_vuetify = "\ue8de"
	# CHAR : 
	dev_vyper = "\ue8df"
	# CHAR : 
	dev_wasm = "\ue8e0"
	# CHAR : 
	dev_webflow = "\ue8e1"
	# CHAR : 
	dev_weblate = "\ue8e2"
	# CHAR : 
	dev_webpack = "\ue8e3"
	# CHAR : 
	dev_webstorm = "\ue8e4"
	# CHAR : 
	dev_windows = "\ue70f"
	# CHAR : 
	dev_windows11 = "\ue8e5"
	# CHAR : 
	dev_woocommerce = "\ue8e6"
	# CHAR : 
	dev_wordpress = "\ue70b"
	# CHAR : 
	dev_xamarin = "\ue8e7"
	# CHAR : 
	dev_xcode = "\ue8e8"
	# CHAR : 
	dev_xd = "\ue8e9"
	# CHAR : 
	dev_xml = "\ue8ea"
	# CHAR : 
	dev_yaml = "\ue8eb"
	# CHAR : 
	dev_yarn = "\ue8ec"
	# CHAR : 
	dev_yii = "\ue782"
	# CHAR : 
	dev_yugabytedb = "\ue8ed"
	# CHAR : 
	dev_yunohost = "\ue8ee"
	# CHAR : 
	dev_zend = "\ue778"
	# CHAR : 
	dev_zig = "\ue8ef"


"""
Tool To Generate nerd Icons Classes

Copyright (c) 2025 Obito. All Rights Reserved.

nerdicons_gen path/to/gen 


"""
import requests,json,io,sys
# fetch Into A .temp_file 
def fetch_data():
    res = requests.get("https://github.com/ryanoasis/nerd-fonts/raw/refs/heads/master/glyphnames.json")
    with open(".temp_icons_map.json","wb") as f:
        f.write(res.content)
def get_perfix(key):
    return key.split("-")[0]
def Gen(path):
    buffers = {}
    with open(".temp_icons_map.json","r") as f:
        data = json.loads(f.read())
    for key,value in data.items():
        if key == "METADATA":
            continue
        perfix = get_perfix(key)
        class_name = perfix.capitalize()
        if perfix not in buffers:
            buffers[perfix] = io.StringIO()

            buffers[perfix].write(f"# This File GEN using nerdicons_gen.py\n\nclass {class_name}:\n")

        buffers[perfix].write(f"\n\t# CHAR : {value['char']}\n\t{key.replace('-','_')} = \"\\u{value['code']}\"")
    for perfix,buffer in buffers.items():
        with open(f"{path}{perfix}.py","w") as f:
            f.write(buffer.getvalue())
def main():
    args = sys.argv
    if len(args) == 1:
        print("unValid Usage \nput --help for help")
    elif len(args) > 1:
        if args[1] == "--help":
            print("Usage:\n\nnerdicons_gen path/to/ \n")
        else:
            Gen(sys.argv[1])
if __name__=="__main__":
    main()
